@@ -215,6 +215,7 @@ static struct lcrt_language_config iqconnect = {
          {"q_cb_rsa",                           "RSA"},
          {"q_cb_tis",                           "TIS"},
          {"q_bt_properties",                    "属性 ..."},
+         {"q_lb_default_command",               "  默认命令:"},
          {"q_cb_show_qconnect",                 "在启动时显示快速连接"},
          {"q_cb_save_session",                  "保存会话"},
          {"q_cb_open_in_a_tab",                 "在新标签中打开"},
@@ -222,6 +223,21 @@ static struct lcrt_language_config iqconnect = {
          {"q_bt_ok",                            "确定"},
          {"q_bt_cancel",                        "关闭"},
          {"q_err_msg",                          "无法创建窗口!"},
+         {"q_sport",                            "  端口:"},
+         {"q_sbaud_rate",                       "  波特率:"},
+         {"q_sdata_bits",                       "  数据位:"},
+         {"q_sparity",                          "  奇偶校验位:"},
+         {"q_sstop_bits",                       "  停止位:"},
+         {"q_sflow_control",                    "流控制"},
+         {"q_shell",                            "  终端:"},
+         {"q_ptitle",                           "密码属性"},
+         {"q_pprompt",                          "修改密码"},
+         {"q_pstore_password",                  "  输入密码:"},
+         {"q_pconfirm_password",                "  确认密码:"},
+         {"p_pcancel",                          "取消"},
+         {"p_pok",                              "确定"},
+         {"p_ppw_unmatch",                      "密码不匹配!"},
+         {"q_snot_found",                       "未找到可执行程序!\n"},
     }
 };
 
@@ -327,7 +343,8 @@ static struct lcrt_language_config iterminal = {
         {"tm_connection_refused",               "连接失败，可能远端服务没有开启!"},
         {"tm_connection_failed",                "用户名或密码错误!"},
         {"tm_connection_prog_not_found",        "没有找到程序\"%s\", 请安装！"},
-        {"tm_connection_not_support",           "当前版本不支持！"}
+        {"tm_connection_not_support",           "当前版本不支持！"},
+        {"tm_serial_error",                     "无法打开 \"%s\",%s."},
     }
 };
 
