@@ -25,18 +25,23 @@ enum {
     LCRT_Q_CONNECT,
     LCRT_Q_SESSION_OPTION,
     LCRT_Q_LB_PROTOCOL,
+    /* for ssh,telnet,rlogin */
     LCRT_Q_LB_HOSTNAME,
     LCRT_Q_LB_USERNAME,
     LCRT_Q_LB_FIREWALL,
     LCRT_Q_LB_PORT,
     LCRT_Q_LB_FRAME,
+    /* for ssh2,ssh1 */
     LCRT_Q_CB_PASSWD,
+    /* for ssh2 */
     LCRT_Q_CB_PUBLICKEY,
     LCRT_Q_CB_KEYBOARD,
     LCRT_Q_CB_GSSAPI,
+    /* for ssh1 */
     LCRT_Q_CB_RSA,
     LCRT_Q_CB_TIS,
     LCRT_Q_BT_PROPERTIES,
+    LCRT_Q_LB_DEFAULT_COMMAND,
     LCRT_Q_CB_SHOW_QCONNECT,
     LCRT_Q_CB_SAVE_SESSION,
     LCRT_Q_CB_OPEN_IN_A_TAB,
@@ -44,6 +49,24 @@ enum {
     LCRT_Q_BT_OK,
     LCRT_Q_BT_CANCEL,
     LCRT_Q_ERR_MSG,
+    /* for protocol serial */
+    LCRT_Q_SPORT,
+    LCRT_Q_SBAUD_RATE,
+    LCRT_Q_SDATA_BITS,
+    LCRT_Q_SPARITY,
+    LCRT_Q_SSTOP_BITS,
+    LCRT_Q_SFLOW_CONTROL,
+    LCRT_Q_SHELL,
+    /* for authentication password */
+    LCRT_Q_PTITLE,
+    LCRT_Q_PPROMPT,
+    LCRT_Q_PSTORE_PASSWORD,
+    LCRT_Q_PCONFIRM_PASSWORD,
+    LCRT_Q_PCANCEL,
+    LCRT_Q_POK,
+    LCRT_Q_PPW_UNMATCH, /* password can not match */
+    /** for shell  */
+    LCRT_Q_SNOT_FOUND,
     LCRT_Q_NUMBER
 };
 #define LCRT_Q_NAME \
@@ -62,13 +85,29 @@ enum {
     "q_cb_rsa", \
     "q_cb_tis", \
     "q_bt_properties", \
+    "q_lb_default_command", \
     "q_cb_show_qconnect", \
     "q_cb_save_session", \
     "q_cb_open_in_a_tab", \
     "q_bt_connect", \
     "q_bt_ok", \
     "q_bt_cancel", \
-    "q_err_msg"
+    "q_err_msg", \
+    "q_sport", \
+    "q_sbaud_rate", \
+    "q_sdata_bits", \
+    "q_sparity", \
+    "q_sstop_bits", \
+    "q_sflow_control", \
+    "q_shell", \
+    "q_ptitle", \
+    "q_pprompt", \
+    "q_pstore_password", \
+    "q_pconfirm_password", \
+    "q_pcancel", \
+    "q_pok", \
+    "q_ppw_unmatch", \
+    "q_snot_found", \
 
 #define LCRT_Q_VALUE \
     "Quick connect", \
@@ -86,13 +125,31 @@ enum {
     "RSA", \
     "TIS", \
     "Properties...", \
+    "  Command:", \
     "Show Quick connect on startup", \
     "Save Session", \
     "Open in a tab", \
     "Connect", \
     "OK", \
     "Cancel", \
-    "There is no memory to create window"
+    "There is no memory to create window" , \
+    /* for protocol serial */ \
+    "  Port:", \
+    "  Baud rate:", \
+    "  Data bits:", \
+    "  Parity:", \
+    "  Stop bits:", \
+    "Flow control", \
+    "  Shell:", \
+    /* for authentication password */ \
+    "Password Properties", \
+    "Change password", \
+    "  Store password:", \
+    "  Confirm password:", \
+    "Cancel", \
+    "OK", \
+    "Password can not match!", \
+    "Shell is not found!\n",
 
 #define LCRT_Q_SHORTCUT \
     {0, 0}
@@ -116,25 +173,12 @@ struct lcrt_qconnect {
     const char *uname;
 
     GtkWidget *q_connect;
-   
+    GtkWidget *q_vbox_spec;
     GtkWidget *q_cb_protocol;
-    GtkWidget *q_et_hostname;
-    GtkWidget *q_et_username;
-    GtkWidget *q_cb_firewall;
-    GtkWidget *q_et_port;
 
-    GtkWidget *q_ssh_frame;
-    GtkWidget *q_vbox_frame;
-    GtkWidget *q_cb_passwd;
-    /*SSH2*/
-    GtkWidget *q_cb_publickey;
-    GtkWidget *q_cb_keyboard;
-    GtkWidget *q_cb_gssapi;
-    /*SSH1*/
-    GtkWidget *q_cb_rsa;
-    GtkWidget *q_cb_tis;
+    lcrt_protocol_t nproto;
 
-    GtkWidget *q_bt_properties;
+    GtkWidget *q_et_default_command;
     GtkWidget *q_cb_show_qconnect;
     GtkWidget *q_cb_save_session;
     GtkWidget *q_cb_open_in_a_tab;
@@ -144,6 +188,9 @@ struct lcrt_qconnect {
     struct lcrtc_qconnect config;
     const char *(*get_db)(struct lcrt_qconnect *lqconnect);
     const char *(*get_tb)(struct lcrt_qconnect *lqconnect);
+
+    void *private_data; /**< the pointer to point to private data of each protocol */
+    const struct lcrt_protocol_callback *ops; /**< callbacks for each protocl  */
 };
 
 int lcrt_create_qconnect(
@@ -152,9 +199,4 @@ int lcrt_create_qconnect(
     lcrt_qconnect_flag_t flag, 
     const char *uname);
 void lcrt_destroy_qconnect(struct lcrt_qconnect *lqconnect);
-int lcrt_qconnect_create_ssh1(struct lcrt_qconnect *lqconnect);
-int lcrt_qconnect_create_ssh2(struct lcrt_qconnect *lqconnect);
-int lcrt_qconnect_destroy_ssh1(struct lcrt_qconnect *lqconnect);
-int lcrt_qconnect_destroy_ssh2(struct lcrt_qconnect *lqconnect);
-
 #endif
